@@ -31,17 +31,20 @@ class ImageGenerator(metaclass=abc.ABCMeta):
     def augment(
         self,
         img_batch,
+        target_img_width,
+        target_img_height,
         num_crops=32,
         crop_scaler=1,
     ):
-        pad_size = self.target_img_size // 2
+        x_pad_size = target_img_width // 2
+        y_pad_size = target_img_height // 2
         img_batch = torch.nn.functional.pad(
             img_batch,
             (
-                pad_size,
-                pad_size,
-                pad_size,
-                pad_size,
+                x_pad_size,
+                x_pad_size,
+                y_pad_size,
+                y_pad_size,
             ),
             mode='constant',
             value=0,
@@ -49,6 +52,8 @@ class ImageGenerator(metaclass=abc.ABCMeta):
 
         img_batch = self.aug_transform(img_batch)
 
+        min_img_size = min(target_img_width, target_img_height)
+
         augmented_img_list = []
         for crop in range(num_crops):
             crop_size = int(
@@ -56,23 +61,23 @@ class ImageGenerator(metaclass=abc.ABCMeta):
                     1.2,
                     .3,
                     (),
-                ).clip(.43, 1.9) * self.target_img_size)
+                ).clip(.43, 1.9) * min_img_size)
 
             if crop > num_crops - 4:
-                crop_size = int(self.target_img_size * 1.4)
+                crop_size = int(min_img_size * 1.4)
 
             offsetx = torch.randint(
                 0,
-                int(self.target_img_size * 2 - crop_size),
+                int(target_img_width * 2 - crop_size),
                 (),
             )
             offsety = torch.randint(
                 0,
-                int(self.target_img_size * 2 - crop_size),
+                int(target_img_height * 2 - crop_size),
                 (),
             )
-            augmented_img = img_batch[:, :, offsetx:offsetx + crop_size,
-                                      offsety:offsety + crop_size, ]
+            augmented_img = img_batch[:, :, offsety:offsety + crop_size,
+                                      offsetx:offsetx + crop_size, ]
             augmented_img = torch.nn.functional.interpolate(
                 augmented_img,
                 (int(224 * crop_scaler), int(224 * crop_scaler)),
