@@ -7,7 +7,6 @@ from typing import *
 
 import torch
 import torchvision
-import numpy as np
 from PIL import Image
 from omegaconf import OmegaConf
 from forks.taming_transformers.taming.models.vqgan import VQModel
@@ -37,8 +36,10 @@ class TamingDecoder(ImageGenerator):
         modeling_ckpt_path = os.path.join(modeling_cache_dir, 'last.ckpt')
         if not os.path.exists(modeling_ckpt_path):
             modeling_ckpt_url = 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1'
-            
-            logging.info(f"Downloading pre-trained weights for VQ-GAN from {modeling_ckpt_url}")
+
+            logging.info(
+                f"Downloading pre-trained weights for VQ-GAN from {modeling_ckpt_url}"
+            )
             results = requests.get(modeling_ckpt_url, allow_redirects=True)
 
             with open(modeling_ckpt_path, "wb") as ckpt_file:
@@ -48,8 +49,10 @@ class TamingDecoder(ImageGenerator):
         modeling_config_path = os.path.join(modeling_cache_dir, 'model.yaml')
         if not os.path.exists(modeling_config_path):
             modeling_config_url = 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml'
-            
-            logging.info("Downloading `model.yaml` from vipermu taming-transformers fork")
+
+            logging.info(
+                "Downloading `model.yaml` from vipermu taming-transformers fork"
+            )
             results = requests.get(modeling_config_url, allow_redirects=True)
 
             with open(modeling_config_path, "wb") as yaml_file:
@@ -116,6 +119,7 @@ class TamingDecoder(ImageGenerator):
         num_generations: int = 200,
         num_random_crops: int = 20,
         img_batch=None,
+        **kwargs,
     ):
         batch_size = 1
 
@@ -157,7 +161,12 @@ class TamingDecoder(ImageGenerator):
             z = self.vqgan_model.post_quant_conv(z_logits)
             x_rec = self.vqgan_model.decoder(z)
             x_rec = (x_rec.clip(-1, 1) + 1) / 2
-            x_rec_stacked = self.augment(x_rec, num_crops=num_random_crops)
+            x_rec_stacked = self.augment(
+                x_rec,
+                num_crops=num_random_crops,
+                target_img_width=self.target_img_size,
+                target_img_height=self.target_img_size,
+            )
 
             loss += 10 * self.compute_clip_loss(x_rec_stacked, prompt)
 
@@ -190,6 +199,7 @@ class TamingDecoder(ImageGenerator):
         self,
         z_logits_list,
         duration_list,
+        **kwargs,
     ):
         gen_img_list = []
         fps = 25
@@ -221,8 +231,7 @@ if __name__ == '__main__':
     img_save_freq = 1
     num_generations = 200
     num_random_crops = 20
-    img_batch=None
-
+    img_batch = None
 
     taming_decoder = TamingDecoder()
     gen_img_list, z_logits_list = taming_decoder.generate_from_prompt(
@@ -232,4 +241,4 @@ if __name__ == '__main__':
         num_generations=num_generations,
         num_random_crops=num_random_crops,
         img_batch=img_batch,
-        )
+    )
